package cn.com.ty.lift.system.settings.service.impl;

import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.system.settings.dao.entity.MaintenanceCompany;
import cn.com.ty.lift.system.settings.dao.entity.model.MaintenanceCompanyRequest;
import cn.com.ty.lift.system.settings.dao.mapper.MaintenanceCompanyMapper;
import cn.com.ty.lift.system.settings.service.IMaintenanceCompanyService;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * <p>
 * 维保公司 服务实现类
 * </p>
 *
 * @author huangy
 * @since 2019-12-09
 */
@Service
public class MaintenanceCompanyServiceImpl extends ServiceImpl<MaintenanceCompanyMapper, MaintenanceCompany> implements IMaintenanceCompanyService {

    @Override
    public RestResponse list(MaintenanceCompanyRequest MaintenanceCompanyRequest) {
        IPage<MaintenanceCompany> maintenanceCompanyPage = new Page<>(
                MaintenanceCompanyRequest.getPageNum(), MaintenanceCompanyRequest.getPageSize());
        maintenanceCompanyPage = this.page(
                maintenanceCompanyPage, new QueryWrapper<MaintenanceCompany>()
                //通过公司名称模糊查找公司信息
                .like(StringUtils.isNotBlank(MaintenanceCompanyRequest.getCompanyName()), "name", MaintenanceCompanyRequest.getCompanyName())
        );
        return RestResponse.ok(maintenanceCompanyPage, ApiConstants.RESULT_SUCCESS, "获取公司列表成功");
    }

    @Override
    @Transactional
    public RestResponse applyTeam(MaintenanceCompanyRequest MaintenanceCompanyRequest) {
        MaintenanceCompany maintenanceCompany = new MaintenanceCompany();
        //设置申请团队信息
        maintenanceCompany.setName(MaintenanceCompanyRequest.getCompanyName());
        maintenanceCompany.setCorporator(MaintenanceCompanyRequest.getCorporator());
        maintenanceCompany.setCreatorId(MaintenanceCompanyRequest.getUserId());
        maintenanceCompany.setRemarks(MaintenanceCompanyRequest.getRemarks());
        boolean saveFlag = this.save(maintenanceCompany);
        if(saveFlag){
            //创建团队成功
            //创建默认角色企业管理员

            //保存成功给团队分配默认菜单

            return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "申请团队成功");
        }
        return RestResponse.error(ApiConstants.RESULT_ERROR, "申请团队失败");
    }
}
